Module: Aws::AgentRegistry

Defined in:
lib/aws-sdk-agentregistry/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/resource.rbs,
lib/aws-sdk-agentregistry/plugins/endpoints.rb,
lib/aws-sdk-agentregistry/endpoint_provider.rb,
lib/aws-sdk-agentregistry/client_api.rb,
lib/aws-sdk-agentregistry/endpoints.rb,
lib/aws-sdk-agentregistry/resource.rb,
lib/aws-sdk-agentregistry/errors.rb,
lib/aws-sdk-agentregistry/client.rb,
lib/aws-sdk-agentregistry/types.rb,
lib/aws-sdk-agentregistry.rb

Overview

This module provides support for Agent Registry. This module is available in the aws-sdk-agentregistry gem.

Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

agent_registry = Aws::AgentRegistry::Client.new
resp = agent_registry.batch_get_discoverable_registry_record(params)

See Client for more information.

Errors

Errors returned from Agent Registry are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::AgentRegistry::Errors::ServiceError
  # rescues all Agent Registry API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Plugins, Types Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.0.0'