Class: Aws::AgentRegistry::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AgentRegistry::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-agentregistry/client.rb,
sig/client.rbs
Overview
An API client for AgentRegistry. To construct a client, you need to configure a :region and :credentials.
client = Aws::AgentRegistry::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetDiscoverableRegistryRecordResponseSuccess, _ListDiscoverableRegistryRecordsResponseSuccess, _SearchDiscoverableRegistryRecordsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_discoverable_registry_record(params = {}) ⇒ Types::BatchGetDiscoverableRegistryRecordResponse
Retrieves multiple discoverable registry records by ID from a single registry.
-
#list_discoverable_registry_records(params = {}) ⇒ Types::ListDiscoverableRegistryRecordsResponse
Lists the discoverable registry records in a registry.
-
#search_discoverable_registry_records(params = {}) ⇒ Types::SearchDiscoverableRegistryRecordsResponse
Searches the discoverable registry records in a registry using a natural language query.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-agentregistry/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
716 717 718 |
# File 'lib/aws-sdk-agentregistry/client.rb', line 716 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
719 720 721 |
# File 'lib/aws-sdk-agentregistry/client.rb', line 719 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_get_discoverable_registry_record(params = {}) ⇒ Types::BatchGetDiscoverableRegistryRecordResponse
Retrieves multiple discoverable registry records by ID from a single
registry. Records that cannot be retrieved are reported individually
in the errors list rather than failing the entire request.
87 |
# File 'sig/client.rbs', line 87
def batch_get_discoverable_registry_record: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 |
# File 'lib/aws-sdk-agentregistry/client.rb', line 689 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AgentRegistry') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-agentregistry' context[:gem_version] = '1.0.0' Seahorse::Client::Request.new(handlers, context) end |
#list_discoverable_registry_records(params = {}) ⇒ Types::ListDiscoverableRegistryRecordsResponse
Lists the discoverable registry records in a registry. You can optionally filter and paginate the results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
103 |
# File 'sig/client.rbs', line 103
def list_discoverable_registry_records: (
|
#search_discoverable_registry_records(params = {}) ⇒ Types::SearchDiscoverableRegistryRecordsResponse
Searches the discoverable registry records in a registry using a natural language query. Returns metadata for the matching records ordered by relevance.
121 |
# File 'sig/client.rbs', line 121
def search_discoverable_registry_records: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
709 710 711 |
# File 'lib/aws-sdk-agentregistry/client.rb', line 709 def waiter_names [] end |