Class: Aws::AgentRegistry::Types::AgentSkillsMdDescriptor
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistry::Types::AgentSkillsMdDescriptor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistry/types.rb
Overview
Base mixin for agent skills markdown descriptor content
Constant Summary collapse
- SENSITIVE =
[:data]
Instance Attribute Summary collapse
-
#data ⇒ String
Descriptor payload data.
-
#data_schema_version ⇒ String
Version of the descriptor type schema.
-
#source ⇒ Types::DescriptorSource
The source location from which the agent skills markdown content was retrieved.
Instance Attribute Details
#data ⇒ String
Descriptor payload data
107 108 109 110 111 112 113 |
# File 'lib/aws-sdk-agentregistry/types.rb', line 107 class AgentSkillsMdDescriptor < Struct.new( :data, :data_schema_version, :source) SENSITIVE = [:data] include Aws::Structure end |
#data_schema_version ⇒ String
Version of the descriptor type schema
107 108 109 110 111 112 113 |
# File 'lib/aws-sdk-agentregistry/types.rb', line 107 class AgentSkillsMdDescriptor < Struct.new( :data, :data_schema_version, :source) SENSITIVE = [:data] include Aws::Structure end |
#source ⇒ Types::DescriptorSource
The source location from which the agent skills markdown content was retrieved.
107 108 109 110 111 112 113 |
# File 'lib/aws-sdk-agentregistry/types.rb', line 107 class AgentSkillsMdDescriptor < Struct.new( :data, :data_schema_version, :source) SENSITIVE = [:data] include Aws::Structure end |