Class: Aws::AgentRegistry::Types::Descriptors

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistry/types.rb

Overview

The protocol-specific descriptors that describe how to connect to and use the registry record.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#a2a_agent_cardTypes::A2aAgentCardDescriptor

The A2A agent card descriptor, populated when the record type is AGENT.



254
255
256
257
258
259
260
261
# File 'lib/aws-sdk-agentregistry/types.rb', line 254

class Descriptors < Struct.new(
  :mcp_server,
  :a2a_agent_card,
  :agent_skills_definition,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end

#agent_skills_definitionTypes::AgentSkillsDefinitionDescriptor

The agent skills definition descriptor, populated when the record type is SKILL.



254
255
256
257
258
259
260
261
# File 'lib/aws-sdk-agentregistry/types.rb', line 254

class Descriptors < Struct.new(
  :mcp_server,
  :a2a_agent_card,
  :agent_skills_definition,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end

#customTypes::CustomDescriptor

The custom descriptor, populated when the record type is CUSTOM.



254
255
256
257
258
259
260
261
# File 'lib/aws-sdk-agentregistry/types.rb', line 254

class Descriptors < Struct.new(
  :mcp_server,
  :a2a_agent_card,
  :agent_skills_definition,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end

#mcp_serverTypes::McpServerDescriptor

The MCP server descriptor, populated when the record type is MCP.



254
255
256
257
258
259
260
261
# File 'lib/aws-sdk-agentregistry/types.rb', line 254

class Descriptors < Struct.new(
  :mcp_server,
  :a2a_agent_card,
  :agent_skills_definition,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end