Class: Aws::AgentRegistry::Types::McpServerAdditionalData
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistry::Types::McpServerAdditionalData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistry/types.rb
Overview
Additional data for an MCP server descriptor
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tools ⇒ Types::McpToolsDescriptor
The MCP tools descriptor that defines the tools exposed by the MCP server.
Instance Attribute Details
#tools ⇒ Types::McpToolsDescriptor
The MCP tools descriptor that defines the tools exposed by the MCP server.
419 420 421 422 423 |
# File 'lib/aws-sdk-agentregistry/types.rb', line 419 class McpServerAdditionalData < Struct.new( :tools) SENSITIVE = [] include Aws::Structure end |